@@ -36,12 +36,12 @@
 
 #include "files.h"
 
-pcre *
+pcre2_code *
 initialize_regexp(const char *regexp_str);
 
 int
 match_tag_regexps(struct media_file_tags *, struct tag_regexes *);
 
 int
-match_tag_regexps_any(struct media_file_tags *, pcre *);
+match_tag_regexps_any(struct media_file_tags *, pcre2_code *);
 #endif
